Remove tiered jit option.

All interpreters now support it. This fixes 566-polymorphic-inlining

Test: 566-polymorphic-inlining
Bug: 112676029
Bug: 152392499
Change-Id: I1362f1aba425aa69ee7ed227b41016c7cc2306c6
diff --git a/runtime/jit/jit.h b/runtime/jit/jit.h
index 5aa53ff..0a5e7d3 100644
--- a/runtime/jit/jit.h
+++ b/runtime/jit/jit.h
@@ -117,10 +117,6 @@
     return use_jit_compilation_;
   }
 
-  bool UseTieredJitCompilation() const {
-    return use_tiered_jit_compilation_;
-  }
-
   void SetUseJitCompilation(bool b) {
     use_jit_compilation_ = b;
   }
@@ -152,7 +148,6 @@
   static uint32_t RoundUpThreshold(uint32_t threshold);
 
   bool use_jit_compilation_;
-  bool use_tiered_jit_compilation_;
   bool use_baseline_compiler_;
   size_t code_cache_initial_capacity_;
   size_t code_cache_max_capacity_;
@@ -167,7 +162,6 @@
 
   JitOptions()
       : use_jit_compilation_(false),
-        use_tiered_jit_compilation_(false),
         use_baseline_compiler_(false),
         code_cache_initial_capacity_(0),
         code_cache_max_capacity_(0),
diff --git a/runtime/parsed_options.cc b/runtime/parsed_options.cc
index 3f5a357..a148854 100644
--- a/runtime/parsed_options.cc
+++ b/runtime/parsed_options.cc
@@ -242,10 +242,6 @@
           .WithType<bool>()
           .WithValueMap({{"false", false}, {"true", true}})
           .IntoKey(M::UseJitCompilation)
-      .Define("-Xusetieredjit:_")
-          .WithType<bool>()
-          .WithValueMap({{"false", false}, {"true", true}})
-          .IntoKey(M::UseTieredJitCompilation)
       .Define("-Xjitinitialsize:_")
           .WithType<MemoryKiB>()
           .IntoKey(M::JITCodeCacheInitialCapacity)
diff --git a/runtime/runtime_options.def b/runtime/runtime_options.def
index 748d01c..53d15bf 100644
--- a/runtime/runtime_options.def
+++ b/runtime/runtime_options.def
@@ -76,7 +76,6 @@
 RUNTIME_OPTIONS_KEY (bool,                UseTLAB,                        (kUseTlab || kUseReadBarrier))
 RUNTIME_OPTIONS_KEY (bool,                EnableHSpaceCompactForOOM,      true)
 RUNTIME_OPTIONS_KEY (bool,                UseJitCompilation,              true)
-RUNTIME_OPTIONS_KEY (bool,                UseTieredJitCompilation,        interpreter::IsNterpSupported())
 RUNTIME_OPTIONS_KEY (bool,                DumpNativeStackOnSigQuit,       true)
 RUNTIME_OPTIONS_KEY (bool,                MadviseRandomAccess,            false)
 RUNTIME_OPTIONS_KEY (JniIdType,           OpaqueJniIds,                   JniIdType::kDefault)  // -Xopaque-jni-ids:{true, false, swapable}
diff --git a/test/566-polymorphic-inlining/polymorphic_inline.cc b/test/566-polymorphic-inlining/polymorphic_inline.cc
index 3ca5989..191a942 100644
--- a/test/566-polymorphic-inlining/polymorphic_inline.cc
+++ b/test/566-polymorphic-inlining/polymorphic_inline.cc
@@ -59,11 +59,6 @@
     return;
   }
 
-  if (kIsDebugBuild) {
-    // A debug build might often compile the methods without profiling informations filled.
-    return;
-  }
-
   do_checks(cls, "$noinline$testInvokeVirtual");
   do_checks(cls, "$noinline$testInvokeInterface");
   do_checks(cls, "$noinline$testInvokeInterface2");
diff --git a/runtime/jit/jit.cc b/runtime/jit/jit.cc
index 8899fa4..4921a99 100644
--- a/runtime/jit/jit.cc
+++ b/runtime/jit/jit.cc
@@ -90,8 +90,6 @@
 JitOptions* JitOptions::CreateFromRuntimeArguments(const RuntimeArgumentMap& options) {
   auto* jit_options = new JitOptions;
   jit_options->use_jit_compilation_ = options.GetOrDefault(RuntimeArgumentMap::UseJitCompilation);
-  jit_options->use_tiered_jit_compilation_ =
-      options.GetOrDefault(RuntimeArgumentMap::UseTieredJitCompilation);
 
   jit_options->code_cache_initial_capacity_ =
       options.GetOrDefault(RuntimeArgumentMap::JITCodeCacheInitialCapacity);
@@ -1565,9 +1563,9 @@
     return;
   }
   // We arrive here after a baseline compiled code has reached its baseline
   // hotness threshold. If tiered compilation is enabled, enqueue a compilation
   // task that will compile optimize the method.
-  if (options_->UseTieredJitCompilation()) {
+  if (!options_->UseBaselineCompiler()) {
     thread_pool_->AddTask(
         self,
         new JitCompileTask(method,
@@ -1565,9 +1563,9 @@
   }
   // We arrive here after a baseline compiled code has reached its baseline
-  // hotness threshold. If tiered compilation is enabled, enqueue a compilation
+  // hotness threshold. If we're not only using the baseline compiler, enqueue a compilation
   // task that will compile optimize the method.